import logging

from django.contrib.auth import get_user_model
from rest_framework.authtoken.admin import User
from rest_framework.test import APIClient

import pytest

from greg.models import Sponsor, OrganizationalUnit, RoleType
from gregui.models import GregUserProfile

# faker spams the logs with localisation warnings
# see https://github.com/joke2k/faker/issues/753
logging.getLogger("faker").setLevel(logging.ERROR)


@pytest.fixture
def client() -> APIClient:
    client = APIClient()
    return client


@pytest.fixture
def unit_foo() -> OrganizationalUnit:
    ou = OrganizationalUnit.objects.create(orgreg_id="12345", name_en="foo_unit")
    return OrganizationalUnit.objects.get(id=ou.id)


@pytest.fixture
def role_type_foo() -> RoleType:
    rt = RoleType.objects.create(identifier="role_foo", name_en="Role Foo")
    return RoleType.objects.get(id=rt.id)


@pytest.fixture
def sponsor_guy(unit_foo: OrganizationalUnit) -> Sponsor:
    sponsor = Sponsor.objects.create(
        feide_id="guy@example.org", first_name="Sponsor", last_name="Guy"
    )
    sponsor.units.add(unit_foo, through_defaults={"hierarchical_access": False})
    return Sponsor.objects.get(id=sponsor.id)


@pytest.fixture
def user_sponsor(sponsor_guy: Sponsor) -> User:
    user_model = get_user_model()

    # Create a user and link him to a sponsor
    user = user_model.objects.create(
        username="test_sponsor",
        email="test@example.org",
        first_name="Test",
        last_name="Sponsor",
    )
    GregUserProfile.objects.create(user=user, sponsor=sponsor_guy)

    # This user is a sponsor for unit_foo
    return user
